<?php
/**
 * Plugin Name: DesignBro
 * Description: DesignBro business name generator helps creating short, brandable business name and claim the domain in seconds. 100% free brand name generator.
 * Version: 1.0
 * Author: DesignBro
 * Author URI: https://designbro.com/
 */

/**
 * @internal never define functions inside callbacks.
 * these functions could be run multiple times; this would result in a fatal error.
 */
 add_filter('plugin_action_links_'.plugin_basename(__FILE__), 'designbro_add_plugin_page_settings_link');
function designbro_add_plugin_page_settings_link( $links ) {
	$links[] = '<a href="' .
		admin_url( 'admin.php?page=designbro' ) .
		'">' . __('Settings') . '</a>';
	return $links;
}
/**
 * custom option and settings
 */
function designbro_settings_init() {
    // Register a new setting for "designbro" page.
    register_setting( 'designbro', 'designbro_options' );
 
    // Register a new section in the "designbro" page.
    add_settings_section(
        'designbro_section_developers',
        __( '', 'designbro' ), 'designbro_section_developers_callback',
        'designbro'
    );
 
    // Register a new field in the "designbro_section_developers" section, inside the "designbro" page.
    add_settings_field(
        'designbro_button_color', 
		__( 'Submit button color', 'designbro' ),
        'designbro_field_button_color',
        'designbro',
        'designbro_section_developers',
        array(
            'label_for'         => 'designbro_field_button_color',
            'class'             => 'designbro_row',
            'designbro_custom_data' => 'custom',
        )
    );
}
 
/**
 * Register our designbro_settings_init to the admin_init action hook.
 */
add_action( 'admin_init', 'designbro_settings_init' );
 
 
/**
 * Custom option and settings:
 *  - callback functions
 */
 
 
/**
 * Developers section callback function.
 *
 * @param array $args  The settings array, defining title, id, callback.
 */
function designbro_section_developers_callback( $args ) {
    ?>
    <p id="<?php echo esc_attr( $args['id'] ); ?>"><?php esc_html_e( '', 'designbro' ); ?></p>
    <?php
}
 
/**
 * Pill field callbakc function.
 *
 * WordPress has magic interaction with the following keys: label_for, class.
 * - the "label_for" key value is used for the "for" attribute of the <label>.
 * - the "class" key value is used for the "class" attribute of the <tr> containing the field.
 * Note: you can add custom key value pairs to be used inside your callbacks.
 *
 * @param array $args
 */
function designbro_field_button_color( $args ) {
    // Get the value of the setting we've registered with register_setting()
    $options = get_option( 'designbro_options' );
	$designbro_field_button_color = "";
	$designbro_field_button_color = $options["designbro_field_button_color"];
	if(empty($designbro_field_button_color)){
		$designbro_field_button_color = "";
	}
    ?>
	
    <input
            id="<?php echo esc_attr( $args['label_for'] ); ?>"
            data-custom="<?php echo esc_attr( $args['designbro_custom_data'] ); ?>"
            name="designbro_options[<?php echo esc_attr( $args['label_for'] ); ?>]"
			type="text" placeholder="#000000" value="<?php if(!empty($designbro_field_button_color)){echo $designbro_field_button_color;}?>" class="color">

    <?php
}
 
/**
 * Add the top level menu page.
 */
function designbro_options_page() {
    add_menu_page(
        'designbro',
        'DesignBro Settings',
        'manage_options',
        'designbro',
        'designbro_options_page_html'
    );
}
 
 
/**
 * Register our designbro_options_page to the admin_menu action hook.
 */
add_action( 'admin_menu', 'designbro_options_page' );
 
 
/**
 * Top level menu callback function
 */
function designbro_options_page_html() {
    // check user capabilities
    if ( ! current_user_can( 'manage_options' ) ) {
        return;
    }
 
    // add error/update messages
 
    // check if the user have submitted the settings
    // WordPress will add the "settings-updated" $_GET parameter to the url
    if ( isset( $_GET['settings-updated'] ) ) {
        // add settings saved message with the class of "updated"
        add_settings_error( 'designbro_messages', 'designbro_message', __( 'Settings Saved', 'designbro' ), 'updated' );
    }
 
    // show error/update messages
    settings_errors( 'designbro_messages' );
    ?>
    <div class="wrap">
        <h1><?php echo __( 'Business Name Generator Settings', 'designbro' )?></h1>
        <p><?php echo __( 'You can insert the business name generator into your page with the following shortcode: [dbro_display_form]', 'designbro' )?></p>
		<form action="options.php" method="post">
            <?php
            // output security fields for the registered setting "designbro"
            settings_fields( 'designbro' );
            // output setting sections and their fields
            // (sections are registered for "designbro", each field is registered to a specific section)
            do_settings_sections( 'designbro' );
            // output save settings button
            submit_button( 'Save Settings' );
            ?>
        </form>
		<p><?php echo __( 'Made by <a href="https://designbro.com/" target="_blank">DesignBro</a>', 'designbro' )?></p>
    </div>
    <?php
}

function dbro_scripts() {
    wp_enqueue_style( 'dbro-style', plugin_dir_url( __FILE__ ) . 'css/style.css', array(), '1.0', 'all');
	wp_enqueue_style( 'dbro-font-awesome', plugin_dir_url( __FILE__ ) . 'css/font-awesome.min.css', array(), '4.7.0', 'all');
	
	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'dbro-bootstrap', plugin_dir_url( __FILE__ ) . 'js/bootstrap.min.js', array(), '5.0.0', false );
	wp_enqueue_script( 'dbro-name-generator', plugin_dir_url( __FILE__ ) . 'js/name-generator.js', array(), '1.0.0', true );
    wp_enqueue_script( 'dbro-index', plugin_dir_url( __FILE__ ) . 'js/index.js', array(), '1.0.0', true );
}
add_action( 'wp_enqueue_scripts', 'dbro_scripts' );
function dbro_display_form_func( $atts ) {
	$options = get_option( 'designbro_options' );
	$designbro_field_button_color = "";
	$designbro_field_button_color = $options["designbro_field_button_color"];
	if(empty($designbro_field_button_color)){
		$designbro_field_button_color = "";
	}
    $out='<div class="designbro-form-main">';
    $out.='<form id="designbro-form" class="designbro-input-form">';
    $out.='<label>Enter Your Keywords: </label>';
    $out.="<input type='text' class='designbro-input input' id='designbro-input' value=''>";    
    $out.="<button class='designbro-submit submit' style='background-color:".$designbro_field_button_color."'>Generate</button>";
    $out.='</form>';
    $out.='</div>';
    $out.="<div id='designbro-results' class='designbro-results-list'></div>";
	$out.='<p class="designbro-poweredby">Powered by <a href="https://designbro.com/" target="_blank">DesignBro</a></p>';
    return $out;
}
add_shortcode( 'dbro_display_form', 'dbro_display_form_func' );
?>